package view;

import controller.SpaceInvaderGame;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

// Represents the main window in which the space invaders game is played.
@SuppressWarnings("serial")
public class Application extends JFrame {

  private static final int INTERVAL = 20;
  private SpaceInvaderGame game;
  private GamePanel gamePanel;
  private ScorePanel scorePanel;
  private Timer t;

  // Constructs main window
  // sets up window in which Space Invaders game will be played
  public Application() {
    super("Space Invaders");
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    setUndecorated(true);
    game = new SpaceInvaderGame();
    gamePanel = new GamePanel(game);
    scorePanel = new ScorePanel(game);
    add(gamePanel);
    add(scorePanel, BorderLayout.NORTH);
    addKeyListener(new KeyHandler());
    pack();
    centreOnScreen();
    setVisible(true);
    addTimer();
    t.start();
  }

  // Set up timer
  // initializes a timer that updates game each INTERVAL milliseconds
  private void addTimer() {
    t = new Timer(INTERVAL, new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent ae) {
        game.update();
        gamePanel.repaint();
        scorePanel.update();
      }
    });
  }

  // Centres frame on desktop
  // location of frame is set so frame is centred on desktop
  private void centreOnScreen() {
    Dimension scrn = Toolkit.getDefaultToolkit().getScreenSize();
    setLocation((scrn.width - getWidth()) / 2, (scrn.height - getHeight()) / 2);
  }

  // A key handler to respond to key events
  private class KeyHandler extends KeyAdapter {
    @Override
    public void keyPressed(KeyEvent e) {
      game.keyPressed(e.getKeyCode());
    }
  }
}
